@@ -25,27 +25,17 @@
 #include "gnunet_chat_file.h"
 
 #include "gnunet_chat_context.h"
+#include "gnunet_chat_handle.h"
 
-#include <limits.h>
+#include <gnunet/gnunet_common.h>
+#include <gnunet/gnunet_fs_service.h>
+#include <string.h>
 
-struct GNUNET_CHAT_File*
-file_create_from_message (struct GNUNET_CHAT_Handle *handle,
-			                    const struct GNUNET_MESSENGER_MessageFile *message)
+static void
+file_initialize (struct GNUNET_CHAT_File *file)
 {
-  GNUNET_assert((handle) && (message) && (message->name));
+  GNUNET_assert(file);
 
-  struct GNUNET_CHAT_File* file = GNUNET_new(struct GNUNET_CHAT_File);
-
-  file->handle = handle;
-
-  file->name = GNUNET_strndup(message->name, NAME_MAX);
-
-  GNUNET_memcpy(&(file->key), &(message->key), sizeof(file->key));
-  GNUNET_memcpy(&(file->hash), &(message->hash), sizeof(file->hash));
-
-  file->meta = GNUNET_FS_meta_data_create();
-
-  file->uri = GNUNET_FS_uri_parse(message->uri, NULL);
   file->download = NULL;
   file->publish = NULL;
   file->unindex = NULL;
@@ -63,6 +53,69 @@ file_create_from_message (struct GNUNET_CHAT_Handle *handle,
   file->preview = NULL;
 
   file->user_pointer = NULL;
+}
+
+struct GNUNET_CHAT_File*
+file_create_from_message (struct GNUNET_CHAT_Handle *handle,
+			                    const struct GNUNET_MESSENGER_MessageFile *message)
+{
+  GNUNET_assert((handle) && (message) && (message->uri));
+
+  struct GNUNET_CHAT_File* file = GNUNET_new(struct GNUNET_CHAT_File);
+
+  if (!file)
+    return NULL;
+
+  file->handle = handle;
+  file->name = GNUNET_strndup(message->name, NAME_MAX);
+
+  file->key = GNUNET_new(struct GNUNET_CRYPTO_SymmetricSessionKey);
+
+  if (!(file->key))
+  {
+    GNUNET_free(file);
+    return NULL;
+  }
+
+  GNUNET_memcpy(file->key, &(message->key),
+                sizeof(struct GNUNET_CRYPTO_SymmetricSessionKey));
+  GNUNET_memcpy(&(file->hash), &(message->hash), sizeof(file->hash));
+
+  file->meta = GNUNET_FS_meta_data_create();
+  file->uri = GNUNET_FS_uri_parse(message->uri, NULL);
+
+  file_initialize(file);
+
+  return file;
+}
+
+struct GNUNET_CHAT_File*
+file_create_from_chk_uri (struct GNUNET_CHAT_Handle *handle,
+                          const struct GNUNET_FS_Uri *uri)
+{
+  GNUNET_assert((handle) && (uri));
+
+  const struct GNUNET_HashCode *hash = GNUNET_FS_uri_chk_get_file_hash(uri);
+
+  if (!hash)
+    return NULL;
+
+  struct GNUNET_CHAT_File* file = GNUNET_new(struct GNUNET_CHAT_File);
+
+  if (!file)
+    return NULL;
+
+  file->handle = handle;
+  file->name = NULL;
+
+  file->key = NULL;
+
+  GNUNET_memcpy(&(file->hash), hash, sizeof(file->hash));
+
+  file->meta = GNUNET_FS_meta_data_create();
+  file->uri = GNUNET_FS_uri_dup(uri);
+  
+  file_initialize(file);
 
   return file;
 }
@@ -73,37 +126,40 @@ file_create_from_disk (struct GNUNET_CHAT_Handle *handle,
                        const struct GNUNET_HashCode *hash,
                        const struct GNUNET_CRYPTO_SymmetricSessionKey *key)
 {
-  GNUNET_assert((handle) && (name) && (hash) && (key));
+  GNUNET_assert((handle) && (name) && (hash));
 
   struct GNUNET_CHAT_File* file = GNUNET_new(struct GNUNET_CHAT_File);
 
-  file->handle = handle;
+  if (!file)
+    return NULL;
 
+  file->handle = handle;
   file->name = GNUNET_strndup(name, NAME_MAX);
 
-  GNUNET_memcpy(&(file->key), key, sizeof(file->key));
+  if (!key)
+  {
+    file->key = NULL;
+    goto skip_key;
+  }
+
+  file->key = GNUNET_new(struct GNUNET_CRYPTO_SymmetricSessionKey);
+
+  if (!(file->key))
+  {
+    GNUNET_free(file);
+    return NULL;
+  }
+
+  GNUNET_memcpy(file->key, key,
+                sizeof(struct GNUNET_CRYPTO_SymmetricSessionKey));
+
+skip_key:
   GNUNET_memcpy(&(file->hash), hash, sizeof(file->hash));
 
   file->meta = GNUNET_FS_meta_data_create();
-
   file->uri = NULL;
-  file->download = NULL;
-  file->publish = NULL;
-  file->unindex = NULL;
 
-  file->upload_head = NULL;
-  file->upload_tail = NULL;
-
-  file->download_head = NULL;
-  file->download_tail = NULL;
-
-  file->unindex_head = NULL;
-  file->unindex_tail = NULL;
-
-  file->status = 0;
-  file->preview = NULL;
-
-  file->user_pointer = NULL;
+  file_initialize(file);
 
   return file;
 }
@@ -114,6 +170,40 @@ file_destroy (struct GNUNET_CHAT_File *file)
   GNUNET_assert(file);
 
   struct GNUNET_CHAT_FileUpload *upload;
+  struct GNUNET_CHAT_FileDownload *download;
+  struct GNUNET_CHAT_FileUnindex *unindex;
+
+  if (!(file->preview))
+    goto skip_preview;
+
+  if (!(file->key))
+    goto skip_filename;
+
+  char *filename = handle_create_file_path(
+    file->handle, &(file->hash)
+  );
+
+  if (!filename)
+    goto skip_filename;
+
+  if (0 != strcmp(filename, file->preview))
+    remove(file->preview);
+
+  GNUNET_free(filename);
+
+skip_filename:
+  GNUNET_free(file->preview);
+
+skip_preview:
+  if (file->publish)
+    GNUNET_FS_publish_stop(file->publish);
+
+  if (file->download)
+    GNUNET_FS_download_stop(file->download, GNUNET_NO);
+
+  if (file->unindex)
+    GNUNET_FS_unindex_stop(file->unindex);
+
   while (file->upload_head)
   {
     upload = file->upload_head;
@@ -127,7 +217,6 @@ file_destroy (struct GNUNET_CHAT_File *file)
     GNUNET_free(upload);
   }
 
-  struct GNUNET_CHAT_FileDownload *download;
   while (file->download_head)
   {
     download = file->download_head;
@@ -141,7 +230,6 @@ file_destroy (struct GNUNET_CHAT_File *file)
     GNUNET_free(download);
   }
 
-  struct GNUNET_CHAT_FileUnindex *unindex;
   while (file->unindex_head)
   {
     unindex = file->unindex_head;
@@ -161,6 +249,9 @@ file_destroy (struct GNUNET_CHAT_File *file)
   if (file->meta)
     GNUNET_FS_meta_data_destroy(file->meta);
 
+  if (file->key)
+    GNUNET_free(file->key);
+
   if (file->name)
     GNUNET_free(file->name);
 
@@ -255,8 +346,14 @@ file_update_upload (struct GNUNET_CHAT_File *file,
     return;
 
   struct GNUNET_MESSENGER_Message msg;
+  memset(&msg, 0, sizeof(msg));
+
   msg.header.kind = GNUNET_MESSENGER_KIND_FILE;
-  GNUNET_memcpy(&(msg.body.file.key), &(file->key), sizeof(file->key));
+
+  if (file->key)
+    GNUNET_memcpy(&(msg.body.file.key), file->key,
+                  sizeof(struct GNUNET_CRYPTO_SymmetricSessionKey));
+
   GNUNET_memcpy(&(msg.body.file.hash), &(file->hash), sizeof(file->hash));
   GNUNET_strlcpy(msg.body.file.name, file->name, NAME_MAX);
   msg.body.file.uri = GNUNET_FS_uri_to_string(file->uri);
@@ -265,7 +362,8 @@ file_update_upload (struct GNUNET_CHAT_File *file,
   {
     upload = file->upload_head;
 
-    GNUNET_MESSENGER_send_message(upload->context->room, &msg, NULL);
+    if (upload->context)
+      GNUNET_MESSENGER_send_message(upload->context->room, &msg, NULL);
 
     GNUNET_CONTAINER_DLL_remove(
       file->upload_head,
