@@ -76,11 +76,10 @@ struct GNUNET_CHAT_File
   char *name;
 
   struct GNUNET_HashCode hash;
-  struct GNUNET_CRYPTO_SymmetricSessionKey key;
-
+  struct GNUNET_CRYPTO_SymmetricSessionKey *key;
   struct GNUNET_FS_MetaData *meta;
-
   struct GNUNET_FS_Uri *uri;
+
   struct GNUNET_FS_DownloadContext *download;
   struct GNUNET_FS_PublishContext *publish;
   struct GNUNET_FS_UnindexContext *unindex;
@@ -112,6 +111,18 @@ struct GNUNET_CHAT_File*
 file_create_from_message (struct GNUNET_CHAT_Handle *handle,
 			                    const struct GNUNET_MESSENGER_MessageFile *message);
 
+/**
+ * Creates a chat file handle from a FS CHK URI and
+ * with a selected chat <i>handle</i>.
+ *
+ * @param[in,out] handle Chat handle
+ * @param[in] uri FS CHK URI
+ * @return New chat file handle
+ */
+struct GNUNET_CHAT_File*
+file_create_from_chk_uri (struct GNUNET_CHAT_Handle *handle,
+                          const struct GNUNET_FS_Uri *uri);
+
 /**
  * Creates a chat file handle from a local file on disk
  * under a given <i>name</i> using a <i>hash</i> and a
