@@ -1,6 +1,6 @@
 /*
    This file is part of GNUnet.
-   Copyright (C) 2021--2024 GNUnet e.V.
+   Copyright (C) 2021--2025 GNUnet e.V.
 
    GNUnet is free software: you can redistribute it and/or modify it
    under the terms of the GNU Affero General Public License as published
@@ -25,6 +25,8 @@
 #include "gnunet_chat_context.h"
 #include "gnunet_chat_handle.h"
 
+#include <gnunet/gnunet_messenger_service.h>
+
 #define GNUNET_UNUSED __attribute__ ((unused))
 
 void
@@ -52,8 +54,11 @@ search_group_by_topic(void *cls,
   if (0 == GNUNET_memcmp(&peer, door))
     return;
 
-  const struct GNUNET_HashCode *key = GNUNET_MESSENGER_room_get_key(
-    group->context->room
+  union GNUNET_MESSENGER_RoomKey key;
+  GNUNET_memcpy(
+    &(key.hash),
+    GNUNET_MESSENGER_room_get_key(group->context->room),
+    sizeof(key.hash)
   );
 
   if ((GNUNET_YES == GNUNET_CONTAINER_multipeermap_contains(
@@ -63,11 +68,9 @@ search_group_by_topic(void *cls,
       GNUNET_CONTAINER_MULTIHASHMAPOPTION_UNIQUE_FAST)))
     return;
 
-  struct GNUNET_MESSENGER_Room *room = GNUNET_MESSENGER_enter_room(
+  GNUNET_MESSENGER_enter_room(
     group->handle->messenger,
     door,
-    key
+    &key
   );
-
-  handle_send_room_name(group->handle, room);
 }
