@@ -1,6 +1,6 @@
 /*
    This file is part of GNUnet.
-   Copyright (C) 2021--2024 GNUnet e.V.
+   Copyright (C) 2021--2025 GNUnet e.V.
 
    GNUnet is free software: you can redistribute it and/or modify it
    under the terms of the GNU Affero General Public License as published
@@ -23,7 +23,12 @@
  */
 
 #include "gnunet_chat_invitation.h"
+
+#include "gnunet_chat_context.h"
 #include <gnunet/gnunet_common.h>
+#include <gnunet/gnunet_scheduler_lib.h>
+
+#include "gnunet_chat_invitation_intern.c"
 
 struct GNUNET_CHAT_Invitation*
 invitation_create_from_message (struct GNUNET_CHAT_Context *context,
@@ -35,6 +40,7 @@ invitation_create_from_message (struct GNUNET_CHAT_Context *context,
   struct GNUNET_CHAT_Invitation *invitation = GNUNET_new(struct GNUNET_CHAT_Invitation);
 
   invitation->context = context;
+  invitation->task = NULL;
 
   GNUNET_memcpy(&(invitation->hash), hash, sizeof(invitation->hash));
 
@@ -44,12 +50,32 @@ invitation_create_from_message (struct GNUNET_CHAT_Context *context,
   return invitation;
 }
 
+
 void
 invitation_destroy (struct GNUNET_CHAT_Invitation *invitation)
 {
   GNUNET_assert(invitation);
 
+  if (invitation->task)
+    GNUNET_SCHEDULER_cancel(invitation->task);
+
   GNUNET_PEER_decrement_rcs(&(invitation->door), 1);
 
   GNUNET_free(invitation);
 }
+
+
+void
+invitation_update (struct GNUNET_CHAT_Invitation *invitation)
+{
+  GNUNET_assert(invitation);
+
+  if (invitation->task)
+    return;
+
+  invitation->task = GNUNET_SCHEDULER_add_with_priority(
+    GNUNET_SCHEDULER_PRIORITY_BACKGROUND,
+    cb_invitation_update,
+    invitation
+  );
+}
