@@ -1,6 +1,6 @@
 /*
    This file is part of GNUnet.
-   Copyright (C) 2022--2024 GNUnet e.V.
+   Copyright (C) 2022--2025 GNUnet e.V.
 
    GNUnet is free software: you can redistribute it and/or modify it
    under the terms of the GNU Affero General Public License as published
@@ -63,7 +63,7 @@ call_cb:
 
 void
 cont_lobby_identity_create (void *cls,
-                            const struct GNUNET_CRYPTO_PrivateKey *zone,
+                            const struct GNUNET_CRYPTO_BlindablePrivateKey *zone,
                             enum GNUNET_ErrorCode ec)
 {
   struct GNUNET_CHAT_Lobby *lobby = cls;
@@ -104,8 +104,8 @@ cont_lobby_identity_create (void *cls,
   if (lobby->uri)
     uri_destroy(lobby->uri);
 
-  struct GNUNET_CRYPTO_PublicKey public_zone;
-  GNUNET_CRYPTO_key_get_public(zone, &public_zone);
+  struct GNUNET_CRYPTO_BlindablePublicKey public_zone;
+  GNUNET_CRYPTO_blindable_key_get_public(zone, &public_zone);
 
   char *label;
   util_get_context_label(lobby->context->type, key, &label);
