@@ -40,7 +40,7 @@ struct GNUNET_CHAT_Tool
 
 static enum GNUNET_GenericReturnValue
 accounts_iterate (void *cls,
-                  const struct GNUNET_CHAT_Handle *handle,
+                  struct GNUNET_CHAT_Handle *handle,
                   struct GNUNET_CHAT_Account *account)
 {
   struct GNUNET_CHAT_Tool *tool = cls;
@@ -70,7 +70,7 @@ idle (void *cls)
 static enum GNUNET_GenericReturnValue
 chat_message (void *cls,
               struct GNUNET_CHAT_Context *context,
-              const struct GNUNET_CHAT_Message *message)
+              struct GNUNET_CHAT_Message *message)
 {
   struct GNUNET_CHAT_Tool *tool = cls;
 
@@ -233,6 +233,9 @@ main (int argc,
   struct GNUNET_CHAT_Tool tool;
   memset(&tool, 0, sizeof(tool));
 
+  const struct GNUNET_OS_ProjectData *data;
+  data = GNUNET_OS_project_data_gnunet ();
+
   struct GNUNET_GETOPT_CommandLineOption options[] = {
     GNUNET_GETOPT_option_string(
       'a',
@@ -261,6 +264,7 @@ main (int argc,
   printf("@startuml\n");
 
   enum GNUNET_GenericReturnValue result = GNUNET_PROGRAM_run(
+    data,
     argc,
     argv,
     "libgnunetchat_uml",
